@@ -16,13 +16,13 @@
 import os
 import sys
 import time
-import types
 
-import bunch
 from oslo_log import log as logging
 from oslo_service import service
 import semantic_version
+import six
 
+from muranoagent import bunch
 from muranoagent.common import config
 from muranoagent.common import messaging
 from muranoagent import exceptions as exc
@@ -33,7 +33,7 @@ from muranoagent import execution_result as ex_result
 CONF = config.CONF
 
 LOG = logging.getLogger(__name__)
-max_format_version = semantic_version.Spec('<=2.1.0')
+max_format_version = semantic_version.Spec('<=2.2.0')
 
 
 class MuranoAgent(service.Service):
@@ -47,7 +47,7 @@ class MuranoAgent(service.Service):
             LOG.debug('Loading plugin %s', name)
             __import__(name)
         except Exception:
-            LOG.warn('Cannot load package %s', name, exc_info=True)
+            LOG.warning('Cannot load package %s', name, exc_info=True)
             pass
 
     def _load(self):
@@ -81,7 +81,7 @@ class MuranoAgent(service.Service):
             self._run(plan)
             return
 
-        msg_iterator.next()
+        next(msg_iterator)
 
     def _run(self, plan):
         try:
@@ -118,7 +118,8 @@ class MuranoAgent(service.Service):
             'port': rabbitmq.port,
             'virtual_host': rabbitmq.virtual_host,
             'ssl': rabbitmq.ssl,
-            'ca_certs': rabbitmq.ca_certs.strip() or None
+            'ca_certs': rabbitmq.ca_certs.strip() or None,
+            'insecure': rabbitmq.insecure
         }
         return messaging.MqClient(**connection_params)
 
@@ -134,14 +135,14 @@ class MuranoAgent(service.Service):
                             if msg is not None and isinstance(msg.body, dict):
                                 self._handle_message(msg)
 
+                            delay = 5
                             if msg is not None:
                                 msg.ack()
                                 yield
-                            delay = 5
             except KeyboardInterrupt:
                 break
             except Exception:
-                LOG.warn('Communication error', exc_info=True)
+                LOG.warning('Communication error', exc_info=True)
                 time.sleep(delay)
                 delay = min(delay * 1.2, 60)
 
@@ -163,7 +164,7 @@ class MuranoAgent(service.Service):
 
                 self._send_result(execution_result)
             except ValueError:
-                LOG.warn('Execution result is not produced')
+                LOG.warning('Execution result is not produced')
 
     def _verify_plan(self, plan):
         plan_format_version = semantic_version.Version(
@@ -184,7 +185,7 @@ class MuranoAgent(service.Service):
 
         for attr in ('Scripts', 'Files', 'Options'):
             if attr in plan and not isinstance(
-                    plan[attr], types.DictionaryType):
+                    plan[attr], dict):
                 raise exc.IncorrectFormat(
                     2, '{0} is not a dictionary'.format(attr))
 
@@ -197,7 +198,7 @@ class MuranoAgent(service.Service):
     def _validate_script(self, name, script, plan_format_version, plan):
         for attr in ('Type', 'EntryPoint'):
             if attr not in script or not isinstance(script[attr],
-                                                    types.StringTypes):
+                                                    six.string_types):
                 raise exc.IncorrectFormat(
                     2, 'Incorrect {0} entry in script {1}'.format(
                         attr, name))
@@ -212,7 +213,7 @@ class MuranoAgent(service.Service):
                     2, 'Script {0} misses entry point {1}'.format(
                         name, script['EntryPoint']))
 
-        if plan_format_version in semantic_version.Spec('==2.1.0'):
+        if plan_format_version in semantic_version.Spec('>=2.1.0'):
             if script['Type'] not in ('Application', 'Chef', 'Puppet'):
                 raise exc.IncorrectFormat(
                     2, 'Script has not a valid type {0}'.format(
@@ -226,14 +227,25 @@ class MuranoAgent(service.Service):
                   "::" not in script['EntryPoint']):
                     raise exc.IncorrectFormat(
                         2, 'Wrong EntryPoint {0} for Puppet/Chef '
-                           'executors. :: needed'.format(name,
-                                                         script['EntryPoint']))
+                           'executors. :: needed'.format(script['EntryPoint']))
+
+            for option in script['Options']:
+                if option in ('useBerkshelf', 'berksfilePath'):
+                    if plan_format_version in semantic_version.Spec('<2.2.0'):
+                        raise exc.IncorrectFormat(
+                            2, 'Script has an option {0} invalid '
+                               'for version {1}'.format(option,
+                                                        plan_format_version))
+                    elif script['Type'] != 'Chef':
+                        raise exc.IncorrectFormat(
+                            2, 'Script has an option {0} invalid '
+                               'for type {1}'.format(option, script['Type']))
 
         for additional_file in script.get('Files', []):
                 mns_error = ('Script {0} misses file {1}'.
                              format(name, additional_file))
                 if isinstance(additional_file, dict):
-                    if (additional_file.keys()[0] not in
+                    if (list(additional_file.keys())[0] not in
                             plan.get('Files', {}).keys()):
                         raise exc.IncorrectFormat(2, mns_error)
                 elif additional_file not in plan.get('Files', {}):
